@@ -39,6 +39,7 @@ import net.sourceforge.jnlp.runtime.JNLPRuntime;
 import net.sourceforge.jnlp.util.ClasspathMatcher;
 import net.sourceforge.jnlp.util.UrlUtils;
 import net.sourceforge.jnlp.util.logging.OutputController;
+import static net.sourceforge.jnlp.runtime.Translator.R;
 
 /**
  * <p>
@@ -326,13 +327,40 @@ public class JNLPFile {
      * See PluginBridge
      */
     public String getTitle() {
+        try {
+            return getTitle(false);
+        } catch (MissingTitleException cause) {
+            throw new RuntimeException(cause);
+        }
+    }
+
+    public String getTitle(boolean kill) throws MissingTitleException {
+        String title = getTitleImpl();
+        if (title == null) {
+            title = "";
+
+        }
+        if (title.trim().isEmpty() && kill) {
+            throw new MissingTitleException();
+        }
+        if (title.trim().isEmpty()) {
+            OutputController.getLogger().log(OutputController.Level.WARNING_ALL, R("PMissingElement", R("PMissingTitle")));
+            title = R("PMissingMandatorySubstitution", R("PMissingTitle"));
+            OutputController.getLogger().log(OutputController.Level.WARNING_ALL, R("PMissingMandatoryWarning", R("PMissingTitle")) + ": " + title);
+        } else {
+            OutputController.getLogger().log("Acceptable title tag found, contains: " + title);
+        }
+        return title;
+    }
+
+    private String getTitleImpl() {
         String jnlpTitle = getTitleFromJnlp();
         String manifestTitle = getTitleFromManifest();
         if (jnlpTitle != null && manifestTitle != null) {
             if (jnlpTitle.equals(manifestTitle)) {
                 return jnlpTitle;
             }
-            return jnlpTitle+" ("+manifestTitle+")";
+            return jnlpTitle + " (" + manifestTitle + ")";
         }
         if (jnlpTitle != null && manifestTitle == null) {
             return jnlpTitle;
@@ -341,32 +369,56 @@ public class JNLPFile {
             return manifestTitle;
         }
         String mainClass = getManifestsAttributes().getMainClass();
-        return mainClass;        
+        return mainClass;
     }
-    
+
     /**
-     * @return the JNLP file's best localized title. This method returns the same
-     * value as InformationDesc.getTitle().
+     * @return the JNLP file's best localized title. This method returns the
+     * same value as InformationDesc.getTitle().
      */
     public String getTitleFromJnlp() {
         return getInformation().getTitle();
     }
-    
+
     public String getTitleFromManifest() {
         String inManifestTitle = getManifestsAttributes().getApplicationName();
-        if (inManifestTitle == null && getManifestsAttributes().isLoader()){
+        if (inManifestTitle == null && getManifestsAttributes().isLoader()) {
             OutputController.getLogger().log(OutputController.Level.WARNING_ALL, TITLE_NOT_FOUND);
         }
         return inManifestTitle;
     }
-    
-    
 
     /**
-     * @return the JNLP file's best localized vendor. This method returns the same
-     * value as InformationDesc.getVendor().
+     * @return the JNLP file's best localized vendor. This method returns the
+     * same value as InformationDesc.getVendor().
      */
     public String getVendor() {
+        try {
+            return getVendor(false);
+        } catch (MissingVendorException cause) {
+            throw new RuntimeException(cause);
+        }
+    }
+
+    public String getVendor(boolean kill) throws MissingVendorException {
+        String vendor = getVendorImpl();
+        if (vendor == null) {
+            vendor = "";
+        }
+        if (vendor.trim().isEmpty() && kill) {
+            throw new MissingVendorException();
+        }
+        if (vendor.trim().isEmpty()) {
+            OutputController.getLogger().log(OutputController.Level.WARNING_ALL, R("PMissingElement", R("PMissingVendor")));
+            vendor = R("PMissingMandatorySubstitution", R("PMissingVendor"));
+            OutputController.getLogger().log(OutputController.Level.WARNING_ALL, R("PMissingMandatoryWarning", R("PMissingVendor")) + ": " + vendor);
+        } else {
+            OutputController.getLogger().log("Acceptable vendor tag found, contains: " + vendor);
+        }
+        return vendor;
+    }
+
+    private String getVendorImpl() {
         return getInformation().getVendor();
     }
 
@@ -562,8 +614,12 @@ public class JNLPFile {
                     }
                     if (hasUsableLocale
                             && stringMatches(os, rescDesc.getOS())
-                            && stringMatches(arch, rescDesc.getArch()))
-                        result.addAll(rescDesc.getResources(launchType));
+                            && stringMatches(arch, rescDesc.getArch())) {
+                        List<T> ll = rescDesc.getResources(launchType);
+                        result.addAll(ll);
+                    } else {
+                        //those are skipped
+                    }
                 }
 
                 result.addAll(sharedResources.getResources(launchType));
@@ -774,12 +830,21 @@ public class JNLPFile {
      * @return true if prefixStr is a prefix of any strings in
      * available, or if available is empty or null.
      */
-    private boolean stringMatches(String prefixStr, String available[]) {
-        if (available == null || available.length == 0)
+    static boolean stringMatches(String prefixStr, String available[]) {
+        if (available == null || available.length == 0){
             return true;
+        }
 
-        for (String available1 : available) {
-            if (available1 != null && available1.startsWith(prefixStr)) {
+        for (String candidate : available) {
+            String trimmedPrefix = null;
+            if (prefixStr != null) {
+                trimmedPrefix = prefixStr.split("\\s+")[0];
+            }
+            String trimmedCandidate = null;
+            if (candidate != null) {
+                trimmedCandidate = candidate.split("\\s+")[0];
+            }
+            if (trimmedCandidate != null && trimmedCandidate.startsWith(trimmedPrefix)) {
                 return true;
             }
         }
@@ -1125,7 +1190,7 @@ public class JNLPFile {
         return "Generated from applet from " + createJnlpVendorValue();
     }
 
-    public String createJnlpTitleValue() {
+    private String createJnlpTitleValue() {
         final String location;
         if (getSourceLocation() != null) {
             location = new File(getSourceLocation().getFile()).getName();
@@ -1150,6 +1215,15 @@ public class JNLPFile {
         return getTitle() + " from " + createJnlpTitleValue();
     }
     
+    public String createNameForDesktopFile() {
+        String basicTitle = getTitle();
+        if (basicTitle == null || basicTitle.trim().isEmpty()) {
+            return createJnlpTitleValue().replaceAll(".jnlp$","");
+        } else {
+            return basicTitle;            
+        }
+    }
+    
     //not private for testing purposes
     static String[] splitEntryPoints(String entryPointString) {
         if (entryPointString == null || entryPointString.trim().isEmpty()) {
