@@ -46,6 +46,8 @@ public final class CacheDirectory {
 
     /* Don't allow instantiation of this class */
     private CacheDirectory(){}
+    
+    public static final String INFO_SUFFIX = ".info";
 
     /**
      * Get the structure of directory for keeping track of the protocol and
@@ -56,7 +58,7 @@ public final class CacheDirectory {
     public static void getDirStructure(DirectoryNode root) {
         for (File f : root.getFile().listFiles()) {
             DirectoryNode node = new DirectoryNode(f.getName(), f, root);
-            if (f.isDirectory() || (!f.isDirectory() && !f.getName().endsWith(".info")))
+            if (f.isDirectory() || (!f.isDirectory() && !f.getName().endsWith(INFO_SUFFIX)))
                 root.addChild(node);
             if (f.isDirectory())
                 getDirStructure(node);
@@ -70,11 +72,11 @@ public final class CacheDirectory {
      * @return An ArrayList of DirectoryNode.
      */
     public static ArrayList<DirectoryNode> getLeafData(DirectoryNode root) {
-        ArrayList<DirectoryNode> temp = new ArrayList<DirectoryNode>();
+        ArrayList<DirectoryNode> temp = new ArrayList<>();
         for (DirectoryNode f : root.getChildren()) {
             if (f.isDir())
                 temp.addAll(getLeafData(f));
-            else if (!f.getName().endsWith(".info"))
+            else if (!f.getName().endsWith(INFO_SUFFIX))
                 temp.add(f);
         }
         return temp;
@@ -104,13 +106,13 @@ public final class CacheDirectory {
     /**
      * This will recursively remove the parent folders if they are empty. 
      * 
-     * @param fileNode
+     * @param fileNode node of file which parent is going to be cleaned
      */
     public static void cleanParent(DirectoryNode fileNode) {
         DirectoryNode parent = fileNode.getParent();
         if (parent.getParent() == null)
             return; // Don't delete the root.
-        if (parent.getChildren().size() == 0) {
+        if (parent.getChildren().isEmpty()) {
             FileUtils.deleteWithErrMesg(parent.getFile());
             parent.getParent().removeChild(parent);
             cleanParent(parent);
