@@ -27,6 +27,7 @@ import java.security.PrivilegedExceptionAction;
 import javax.jnlp.BasicService;
 import javax.jnlp.ClipboardService;
 import javax.jnlp.DownloadService;
+import javax.jnlp.DownloadService2;
 import javax.jnlp.ExtensionInstallerService;
 import javax.jnlp.FileOpenService;
 import javax.jnlp.FileSaveService;
@@ -42,6 +43,7 @@ import net.sourceforge.jnlp.runtime.ApplicationInstance;
 import net.sourceforge.jnlp.runtime.JNLPRuntime;
 import net.sourceforge.jnlp.security.SecurityDialogs;
 import net.sourceforge.jnlp.security.SecurityDialogs.AccessType;
+import net.sourceforge.jnlp.security.dialogresults.AccessWarningPaneComplexReturn;
 import net.sourceforge.jnlp.util.logging.OutputController;
 
 /**
@@ -77,6 +79,14 @@ public class ServiceUtil {
     public static DownloadService getDownloadService() {
         return (DownloadService) getService("javax.jnlp.DownloadService");
     }
+    
+    /**
+     * @return the DownloadService reference, or null if the service is
+     * unavailable.
+     */
+    public static DownloadService2 getDownloadService2() {
+        return (DownloadService2) getService("javax.jnlp.DownloadService2");
+    }
 
     /**
      * @return the ExtensionInstallerService reference, or null if the service is
@@ -260,9 +270,12 @@ public class ServiceUtil {
             Boolean b = AccessController.doPrivileged(new PrivilegedAction<Boolean>() {
                 @Override
                 public Boolean run() {
-                    boolean b = SecurityDialogs.showAccessWarningDialogB(tmpType,
-                                tmpApp.getJNLPFile(), tmpExtras);
-                    return b;
+                    AccessWarningPaneComplexReturn r = SecurityDialogs.showAccessWarningDialog(tmpType,
+                            tmpApp.getJNLPFile(), tmpExtras);
+                    if (r == null) {
+                        return false;
+                    }
+                    return r.toBoolean();
                 }
             });
 
